==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ThanosRulerBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ThanosRulerBuilder extends io.fabric8.openshift.api.model.monitoring.v1.ThanosRulerFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.ThanosRulerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.ThanosRuler,io.fabric8.openshift.api.model.monitoring.v1.ThanosRulerBuilder>{
  public ThanosRulerBuilder() {
    this(false);
  }
  public ThanosRulerBuilder(java.lang.Boolean validationEnabled) {
    this(new ThanosRuler(), validationEnabled);
  }
  public ThanosRulerBuilder(io.fabric8.openshift.api.model.monitoring.v1.ThanosRulerFluent<?> fluent) {
    this(fluent, false);
  }
  public ThanosRulerBuilder(io.fabric8.openshift.api.model.monitoring.v1.ThanosRulerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ThanosRuler(), validationEnabled);
  }
  public ThanosRulerBuilder(io.fabric8.openshift.api.model.monitoring.v1.ThanosRulerFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ThanosRuler instance) {
    this(fluent, instance, false);
  }
  public ThanosRulerBuilder(io.fabric8.openshift.api.model.monitoring.v1.ThanosRulerFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ThanosRuler instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ThanosRulerBuilder(io.fabric8.openshift.api.model.monitoring.v1.ThanosRuler instance) {
    this(instance,false);
  }
  public ThanosRulerBuilder(io.fabric8.openshift.api.model.monitoring.v1.ThanosRuler instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.ThanosRulerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.ThanosRuler build() {
    ThanosRuler buildable = new ThanosRuler(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ThanosRulerBuilder that = (ThanosRulerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ThanosRulerBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ThanosRulerBuilder extends ThanosRulerFluentImpl<ThanosRulerBuilder> implements VisitableBuilder<ThanosRuler,ThanosRulerBuilder>{
  public ThanosRulerBuilder() {
    this(false);
  }
  public ThanosRulerBuilder(Boolean validationEnabled) {
    this(new ThanosRuler(), validationEnabled);
  }
  public ThanosRulerBuilder(ThanosRulerFluent<?> fluent) {
    this(fluent, false);
  }
  public ThanosRulerBuilder(ThanosRulerFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ThanosRuler(), validationEnabled);
  }
  public ThanosRulerBuilder(ThanosRulerFluent<?> fluent,ThanosRuler instance) {
    this(fluent, instance, false);
  }
  public ThanosRulerBuilder(ThanosRulerFluent<?> fluent,ThanosRuler instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ThanosRulerBuilder(ThanosRuler instance) {
    this(instance,false);
  }
  public ThanosRulerBuilder(ThanosRuler instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ThanosRulerFluent<?> fluent;
  Boolean validationEnabled;
  public ThanosRuler build() {
    ThanosRuler buildable = new ThanosRuler(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
